@@ -117,8 +117,7 @@ __END__
 
 =head1 NAME
 
-Rose::HTML::Form::Field::PhoneNumber::US::Split - Compound field for US phone
-numbers with separate fields for area code, exchange, and number.
+Rose::HTML::Form::Field::PhoneNumber::US::Split - Compound field for US phone numbers with separate fields for area code, exchange, and number.
 
 =head1 SYNOPSIS
 
@@ -145,24 +144,11 @@ numbers with separate fields for area code, exchange, and number.
 
 =head1 DESCRIPTION
 
-L<Rose::HTML::Form::Field::PhoneNumber::US::Split> is a compound field that
-contains three separate text fields for US phone numbers: one each for area
-code, exchange, and number.  It inherits from both
-L<Rose::HTML::Form::Field::PhoneNumber::US> and
-L<Rose::HTML::Form::Field::Compound>.  It overrides the following methods:
-C<build_field()>, C<coalesce_value()>, C<decompose_value()>, C<html_field()>,
-and C<xhtml_field()>.
+L<Rose::HTML::Form::Field::PhoneNumber::US::Split> is a compound field that contains three separate text fields for US phone numbers: one each for area code, exchange, and number.  It inherits from both L<Rose::HTML::Form::Field::PhoneNumber::US> and L<Rose::HTML::Form::Field::Compound>.  It overrides the following methods: L<build_field()|Rose::HTML::Form::Field::Compound/build_field>, L<coalesce_value()|Rose::HTML::Form::Field::Compound/coalesce_value>, L<decompose_value()|Rose::HTML::Form::Field::Compound/decompose_value>, L<html_field()|Rose::HTML::Form::Field/html_field>, and L<xhtml_field()|Rose::HTML::Form::Field/xhtml_field>.
 
-This is a good example of a compound field that combines separate fields into
-a single value through simple concatenation (plus a separator character). By
-inheriting from L<Rose::HTML::Form::Field::PhoneNumber::US>, it gets the
-validation and inflate/deflate features "for free", leaving it to concentrate
-on the coalesce/decompose features and the building and printing of the
-separate fields that make up the compound field.
+This is a good example of a compound field that combines separate fields into a single value through simple concatenation (plus a separator character). By inheriting from L<Rose::HTML::Form::Field::PhoneNumber::US>, it gets the validation and inflate/deflate features "for free", leaving it to concentrate on the coalesce/decompose features and the building and printing of the separate fields that make up the compound field.
 
-It is important that this class inherits from
-L<Rose::HTML::Form::Field::Compound>. See the
-L<Rose::HTML::Form::Field::Compound> documentation for more information.
+It is important that this class inherits from L<Rose::HTML::Form::Field::Compound>. See the L<Rose::HTML::Form::Field::Compound> documentation for more information.
 
 =head1 SEE ALSO
 
@@ -180,7 +166,7 @@ Uses inflate/deflate to coerce input into a fixed format.
 
 =item L<Rose::HTML::Form::Field::DateTime>
 
-Uses inflate/deflate to convert input to a C<DateTime> object.
+Uses inflate/deflate to convert input to a L<DateTime> object.
 
 =item L<Rose::HTML::Form::Field::DateTime::Range>
 
@@ -188,13 +174,11 @@ A compound field whose internal value consists of more than one object.
 
 =item L<Rose::HTML::Form::Field::DateTime::Split::MonthDayYear>
 
-A compound field that uses inflate/deflate convert input from multiple
-subfields into a C<DateTime> object.
+A compound field that uses inflate/deflate convert input from multiple subfields into a L<DateTime> object.
 
 =item L<Rose::HTML::Form::Field::DateTime::Split::MDYHMS>
 
-A compound field that includes other compound fields and uses inflate/deflate 
-convert input from multiple subfields into a C<DateTime> object.
+A compound field that includes other compound fields and uses inflate/deflate convert input from multiple subfields into a L<DateTime> object.
 
 =back
 
@@ -204,6 +188,4 @@ John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 by John C. Siracusa.  All rights reserved.  This program is
-free software; you can redistribute it and/or modify it under the same terms
-as Perl itself.
+Copyright (c) 2005 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
